Class: Aws::MainframeModernization::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MainframeModernization::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-mainframemodernization/client.rb,
sig/client.rbs
Overview
An API client for MainframeModernization. To construct a client, you need to configure a :region and :credentials.
client = Aws::MainframeModernization::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CancelBatchJobExecutionResponseSuccess, _CreateApplicationResponseSuccess, _CreateDataSetExportTaskResponseSuccess, _CreateDataSetImportTaskResponseSuccess, _CreateDeploymentResponseSuccess, _CreateEnvironmentResponseSuccess, _DeleteApplicationFromEnvironmentResponseSuccess, _DeleteApplicationResponseSuccess, _DeleteEnvironmentResponseSuccess, _GetApplicationResponseSuccess, _GetApplicationVersionResponseSuccess, _GetBatchJobExecutionResponseSuccess, _GetDataSetDetailsResponseSuccess, _GetDataSetExportTaskResponseSuccess, _GetDataSetImportTaskResponseSuccess, _GetDeploymentResponseSuccess, _GetEnvironmentResponseSuccess, _GetSignedBluinsightsUrlResponseSuccess, _ListApplicationVersionsResponseSuccess, _ListApplicationsResponseSuccess, _ListBatchJobDefinitionsResponseSuccess, _ListBatchJobExecutionsResponseSuccess, _ListBatchJobRestartPointsResponseSuccess, _ListDataSetExportHistoryResponseSuccess, _ListDataSetImportHistoryResponseSuccess, _ListDataSetsResponseSuccess, _ListDeploymentsResponseSuccess, _ListEngineVersionsResponseSuccess, _ListEnvironmentsResponseSuccess, _ListTagsForResourceResponseSuccess, _StartApplicationResponseSuccess, _StartBatchJobResponseSuccess, _StopApplicationResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateApplicationResponseSuccess, _UpdateEnvironmentResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_batch_job_execution(params = {}) ⇒ Struct
Cancels the running of a specific batch job execution.
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates a new application with given parameters.
-
#create_data_set_export_task(params = {}) ⇒ Types::CreateDataSetExportTaskResponse
Starts a data set export task for a specific application.
-
#create_data_set_import_task(params = {}) ⇒ Types::CreateDataSetImportTaskResponse
Starts a data set import task for a specific application.
-
#create_deployment(params = {}) ⇒ Types::CreateDeploymentResponse
Creates and starts a deployment to deploy an application into a runtime environment.
-
#create_environment(params = {}) ⇒ Types::CreateEnvironmentResponse
Creates a runtime environment for a given runtime engine.
-
#delete_application(params = {}) ⇒ Struct
Deletes a specific application.
-
#delete_application_from_environment(params = {}) ⇒ Struct
Deletes a specific application from the specific runtime environment where it was previously deployed.
-
#delete_environment(params = {}) ⇒ Struct
Deletes a specific runtime environment.
-
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Describes the details of a specific application.
-
#get_application_version(params = {}) ⇒ Types::GetApplicationVersionResponse
Returns details about a specific version of a specific application.
-
#get_batch_job_execution(params = {}) ⇒ Types::GetBatchJobExecutionResponse
Gets the details of a specific batch job execution for a specific application.
-
#get_data_set_details(params = {}) ⇒ Types::GetDataSetDetailsResponse
Gets the details of a specific data set.
-
#get_data_set_export_task(params = {}) ⇒ Types::GetDataSetExportTaskResponse
Gets the status of a data set import task initiated with the CreateDataSetExportTask operation.
-
#get_data_set_import_task(params = {}) ⇒ Types::GetDataSetImportTaskResponse
Gets the status of a data set import task initiated with the CreateDataSetImportTask operation.
-
#get_deployment(params = {}) ⇒ Types::GetDeploymentResponse
Gets details of a specific deployment with a given deployment identifier.
-
#get_environment(params = {}) ⇒ Types::GetEnvironmentResponse
Describes a specific runtime environment.
-
#get_signed_bluinsights_url(params = {}) ⇒ Types::GetSignedBluinsightsUrlResponse
Gets a single sign-on URL that can be used to connect to AWS Blu Insights.
-
#list_application_versions(params = {}) ⇒ Types::ListApplicationVersionsResponse
Returns a list of the application versions for a specific application.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists the applications associated with a specific Amazon Web Services account.
-
#list_batch_job_definitions(params = {}) ⇒ Types::ListBatchJobDefinitionsResponse
Lists all the available batch job definitions based on the batch job resources uploaded during the application creation.
-
#list_batch_job_executions(params = {}) ⇒ Types::ListBatchJobExecutionsResponse
Lists historical, current, and scheduled batch job executions for a specific application.
-
#list_batch_job_restart_points(params = {}) ⇒ Types::ListBatchJobRestartPointsResponse
Lists all the job steps for a JCL file to restart a batch job.
-
#list_data_set_export_history(params = {}) ⇒ Types::ListDataSetExportHistoryResponse
Lists the data set exports for the specified application.
-
#list_data_set_import_history(params = {}) ⇒ Types::ListDataSetImportHistoryResponse
Lists the data set imports for the specified application.
-
#list_data_sets(params = {}) ⇒ Types::ListDataSetsResponse
Lists the data sets imported for a specific application.
-
#list_deployments(params = {}) ⇒ Types::ListDeploymentsResponse
Returns a list of all deployments of a specific application.
-
#list_engine_versions(params = {}) ⇒ Types::ListEngineVersionsResponse
Lists the available engine versions.
-
#list_environments(params = {}) ⇒ Types::ListEnvironmentsResponse
Lists the runtime environments.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
-
#start_application(params = {}) ⇒ Struct
Starts an application that is currently stopped.
-
#start_batch_job(params = {}) ⇒ Types::StartBatchJobResponse
Starts a batch job and returns the unique identifier of this execution of the batch job.
-
#stop_application(params = {}) ⇒ Struct
Stops a running application.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified resource.
-
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates an application and creates a new version.
-
#update_environment(params = {}) ⇒ Types::UpdateEnvironmentResponse
Updates the configuration details for a specific runtime environment.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2456 2457 2458 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 2456 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2459 2460 2461 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 2459 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2429 2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 2429 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MainframeModernization') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-mainframemodernization' context[:gem_version] = '1.54.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_batch_job_execution(params = {}) ⇒ Struct
Cancels the running of a specific batch job execution.
85 |
# File 'sig/client.rbs', line 85
def cancel_batch_job_execution: (
|
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates a new application with given parameters. Requires an existing runtime environment and application definition file.
99 |
# File 'sig/client.rbs', line 99
def create_application: (
|
#create_data_set_export_task(params = {}) ⇒ Types::CreateDataSetExportTaskResponse
Starts a data set export task for a specific application.
119 |
# File 'sig/client.rbs', line 119
def create_data_set_export_task: (
|
#create_data_set_import_task(params = {}) ⇒ Types::CreateDataSetImportTaskResponse
Starts a data set import task for a specific application.
142 |
# File 'sig/client.rbs', line 142
def create_data_set_import_task: (
|
#create_deployment(params = {}) ⇒ Types::CreateDeploymentResponse
Creates and starts a deployment to deploy an application into a runtime environment.
205 |
# File 'sig/client.rbs', line 205
def create_deployment: (
|
#create_environment(params = {}) ⇒ Types::CreateEnvironmentResponse
Creates a runtime environment for a given runtime engine.
218 |
# File 'sig/client.rbs', line 218
def create_environment: (
|
#delete_application(params = {}) ⇒ Struct
Deletes a specific application. You cannot delete a running application.
254 |
# File 'sig/client.rbs', line 254
def delete_application: (
|
#delete_application_from_environment(params = {}) ⇒ Struct
Deletes a specific application from the specific runtime environment where it was previously deployed. You cannot delete a runtime environment using DeleteEnvironment if any application has ever been deployed to it. This API removes the association of the application with the runtime environment so you can delete the environment smoothly.
263 |
# File 'sig/client.rbs', line 263
def delete_application_from_environment: (
|
#delete_environment(params = {}) ⇒ Struct
Deletes a specific runtime environment. The environment cannot contain deployed applications. If it does, you must delete those applications before you delete the environment.
273 |
# File 'sig/client.rbs', line 273
def delete_environment: (
|
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Describes the details of a specific application.
302 |
# File 'sig/client.rbs', line 302
def get_application: (
|
#get_application_version(params = {}) ⇒ Types::GetApplicationVersionResponse
Returns details about a specific version of a specific application.
318 |
# File 'sig/client.rbs', line 318
def get_application_version: (
|
#get_batch_job_execution(params = {}) ⇒ Types::GetBatchJobExecutionResponse
Gets the details of a specific batch job execution for a specific application.
341 |
# File 'sig/client.rbs', line 341
def get_batch_job_execution: (
|
#get_data_set_details(params = {}) ⇒ Types::GetDataSetDetailsResponse
Gets the details of a specific data set.
360 |
# File 'sig/client.rbs', line 360
def get_data_set_details: (
|
#get_data_set_export_task(params = {}) ⇒ Types::GetDataSetExportTaskResponse
Gets the status of a data set import task initiated with the CreateDataSetExportTask operation.
375 |
# File 'sig/client.rbs', line 375
def get_data_set_export_task: (
|
#get_data_set_import_task(params = {}) ⇒ Types::GetDataSetImportTaskResponse
Gets the status of a data set import task initiated with the CreateDataSetImportTask operation.
388 |
# File 'sig/client.rbs', line 388
def get_data_set_import_task: (
|
#get_deployment(params = {}) ⇒ Types::GetDeploymentResponse
Gets details of a specific deployment with a given deployment identifier.
405 |
# File 'sig/client.rbs', line 405
def get_deployment: (
|
#get_environment(params = {}) ⇒ Types::GetEnvironmentResponse
Describes a specific runtime environment.
438 |
# File 'sig/client.rbs', line 438
def get_environment: (
|
#get_signed_bluinsights_url(params = {}) ⇒ Types::GetSignedBluinsightsUrlResponse
Gets a single sign-on URL that can be used to connect to AWS Blu Insights.
448 449 |
# File 'sig/client.rbs', line 448
def get_signed_bluinsights_url: () -> _GetSignedBluinsightsUrlResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _GetSignedBluinsightsUrlResponseSuccess
|
#list_application_versions(params = {}) ⇒ Types::ListApplicationVersionsResponse
Returns a list of the application versions for a specific application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
457 |
# File 'sig/client.rbs', line 457
def list_application_versions: (
|
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists the applications associated with a specific Amazon Web Services account. You can provide the unique identifier of a specific runtime environment in a query parameter to see all applications associated with that environment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
470 |
# File 'sig/client.rbs', line 470
def list_applications: (
|
#list_batch_job_definitions(params = {}) ⇒ Types::ListBatchJobDefinitionsResponse
Lists all the available batch job definitions based on the batch job resources uploaded during the application creation. You can use the batch job definitions in the list to start a batch job.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
484 |
# File 'sig/client.rbs', line 484
def list_batch_job_definitions: (
|
#list_batch_job_executions(params = {}) ⇒ Types::ListBatchJobExecutionsResponse
Lists historical, current, and scheduled batch job executions for a specific application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
498 |
# File 'sig/client.rbs', line 498
def list_batch_job_executions: (
|
#list_batch_job_restart_points(params = {}) ⇒ Types::ListBatchJobRestartPointsResponse
Lists all the job steps for a JCL file to restart a batch job. This is only applicable for Micro Focus engine with versions 8.0.6 and above.
515 |
# File 'sig/client.rbs', line 515
def list_batch_job_restart_points: (
|
#list_data_set_export_history(params = {}) ⇒ Types::ListDataSetExportHistoryResponse
Lists the data set exports for the specified application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
528 |
# File 'sig/client.rbs', line 528
def list_data_set_export_history: (
|
#list_data_set_import_history(params = {}) ⇒ Types::ListDataSetImportHistoryResponse
Lists the data set imports for the specified application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
541 |
# File 'sig/client.rbs', line 541
def list_data_set_import_history: (
|
#list_data_sets(params = {}) ⇒ Types::ListDataSetsResponse
Lists the data sets imported for a specific application. In Amazon Web Services Mainframe Modernization, data sets are associated with applications deployed on runtime environments. This is known as importing data sets. Currently, Amazon Web Services Mainframe Modernization can import data sets into catalogs using CreateDataSetImportTask.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
554 |
# File 'sig/client.rbs', line 554
def list_data_sets: (
|
#list_deployments(params = {}) ⇒ Types::ListDeploymentsResponse
Returns a list of all deployments of a specific application. A deployment is a combination of a specific application and a specific version of that application. Each deployment is mapped to a particular application version.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
569 |
# File 'sig/client.rbs', line 569
def list_deployments: (
|
#list_engine_versions(params = {}) ⇒ Types::ListEngineVersionsResponse
Lists the available engine versions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
582 |
# File 'sig/client.rbs', line 582
def list_engine_versions: (
|
#list_environments(params = {}) ⇒ Types::ListEnvironmentsResponse
Lists the runtime environments.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
595 |
# File 'sig/client.rbs', line 595
def list_environments: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
608 |
# File 'sig/client.rbs', line 608
def list_tags_for_resource: (
|
#start_application(params = {}) ⇒ Struct
Starts an application that is currently stopped.
617 |
# File 'sig/client.rbs', line 617
def start_application: (
|
#start_batch_job(params = {}) ⇒ Types::StartBatchJobResponse
Starts a batch job and returns the unique identifier of this execution of the batch job. The associated application must be running in order to start the batch job.
627 |
# File 'sig/client.rbs', line 627
def start_batch_job: (
|
#stop_application(params = {}) ⇒ Struct
Stops a running application.
666 |
# File 'sig/client.rbs', line 666
def stop_application: (
|
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to the specified resource.
676 |
# File 'sig/client.rbs', line 676
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified resource.
686 |
# File 'sig/client.rbs', line 686
def untag_resource: (
|
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates an application and creates a new version.
697 |
# File 'sig/client.rbs', line 697
def update_application: (
|
#update_environment(params = {}) ⇒ Types::UpdateEnvironmentResponse
Updates the configuration details for a specific runtime environment.
713 |
# File 'sig/client.rbs', line 713
def update_environment: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2449 2450 2451 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 2449 def waiter_names [] end |