Class: Aws::MainframeModernization::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MainframeModernization::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-mainframemodernization/client.rb
Overview
An API client for MainframeModernization. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::MainframeModernization::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_batch_job_execution(params = {}) ⇒ Struct
Cancels the running of a specific batch job execution.
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates a new application with given parameters.
-
#create_data_set_export_task(params = {}) ⇒ Types::CreateDataSetExportTaskResponse
Starts a data set export task for a specific application.
-
#create_data_set_import_task(params = {}) ⇒ Types::CreateDataSetImportTaskResponse
Starts a data set import task for a specific application.
-
#create_deployment(params = {}) ⇒ Types::CreateDeploymentResponse
Creates and starts a deployment to deploy an application into a runtime environment.
-
#create_environment(params = {}) ⇒ Types::CreateEnvironmentResponse
Creates a runtime environment for a given runtime engine.
-
#delete_application(params = {}) ⇒ Struct
Deletes a specific application.
-
#delete_application_from_environment(params = {}) ⇒ Struct
Deletes a specific application from the specific runtime environment where it was previously deployed.
-
#delete_environment(params = {}) ⇒ Struct
Deletes a specific runtime environment.
-
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Describes the details of a specific application.
-
#get_application_version(params = {}) ⇒ Types::GetApplicationVersionResponse
Returns details about a specific version of a specific application.
-
#get_batch_job_execution(params = {}) ⇒ Types::GetBatchJobExecutionResponse
Gets the details of a specific batch job execution for a specific application.
-
#get_data_set_details(params = {}) ⇒ Types::GetDataSetDetailsResponse
Gets the details of a specific data set.
-
#get_data_set_export_task(params = {}) ⇒ Types::GetDataSetExportTaskResponse
Gets the status of a data set import task initiated with the CreateDataSetExportTask operation.
-
#get_data_set_import_task(params = {}) ⇒ Types::GetDataSetImportTaskResponse
Gets the status of a data set import task initiated with the CreateDataSetImportTask operation.
-
#get_deployment(params = {}) ⇒ Types::GetDeploymentResponse
Gets details of a specific deployment with a given deployment identifier.
-
#get_environment(params = {}) ⇒ Types::GetEnvironmentResponse
Describes a specific runtime environment.
-
#get_signed_bluinsights_url(params = {}) ⇒ Types::GetSignedBluinsightsUrlResponse
Gets a single sign-on URL that can be used to connect to AWS Blu Insights.
-
#list_application_versions(params = {}) ⇒ Types::ListApplicationVersionsResponse
Returns a list of the application versions for a specific application.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists the applications associated with a specific Amazon Web Services account.
-
#list_batch_job_definitions(params = {}) ⇒ Types::ListBatchJobDefinitionsResponse
Lists all the available batch job definitions based on the batch job resources uploaded during the application creation.
-
#list_batch_job_executions(params = {}) ⇒ Types::ListBatchJobExecutionsResponse
Lists historical, current, and scheduled batch job executions for a specific application.
-
#list_batch_job_restart_points(params = {}) ⇒ Types::ListBatchJobRestartPointsResponse
Lists all the job steps for a JCL file to restart a batch job.
-
#list_data_set_export_history(params = {}) ⇒ Types::ListDataSetExportHistoryResponse
Lists the data set exports for the specified application.
-
#list_data_set_import_history(params = {}) ⇒ Types::ListDataSetImportHistoryResponse
Lists the data set imports for the specified application.
-
#list_data_sets(params = {}) ⇒ Types::ListDataSetsResponse
Lists the data sets imported for a specific application.
-
#list_deployments(params = {}) ⇒ Types::ListDeploymentsResponse
Returns a list of all deployments of a specific application.
-
#list_engine_versions(params = {}) ⇒ Types::ListEngineVersionsResponse
Lists the available engine versions.
-
#list_environments(params = {}) ⇒ Types::ListEnvironmentsResponse
Lists the runtime environments.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
-
#start_application(params = {}) ⇒ Struct
Starts an application that is currently stopped.
-
#start_batch_job(params = {}) ⇒ Types::StartBatchJobResponse
Starts a batch job and returns the unique identifier of this execution of the batch job.
-
#stop_application(params = {}) ⇒ Struct
Stops a running application.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified resource.
-
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates an application and creates a new version.
-
#update_environment(params = {}) ⇒ Types::UpdateEnvironmentResponse
Updates the configuration details for a specific runtime environment.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2456 2457 2458 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 2456 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2459 2460 2461 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 2459 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2429 2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 2429 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MainframeModernization') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-mainframemodernization' context[:gem_version] = '1.52.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_batch_job_execution(params = {}) ⇒ Struct
Cancels the running of a specific batch job execution.
504 505 506 507 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 504 def cancel_batch_job_execution(params = {}, = {}) req = build_request(:cancel_batch_job_execution, params) req.send_request() end |
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates a new application with given parameters. Requires an existing runtime environment and application definition file.
580 581 582 583 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 580 def create_application(params = {}, = {}) req = build_request(:create_application, params) req.send_request() end |
#create_data_set_export_task(params = {}) ⇒ Types::CreateDataSetExportTaskResponse
Starts a data set export task for a specific application.
639 640 641 642 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 639 def create_data_set_export_task(params = {}, = {}) req = build_request(:create_data_set_export_task, params) req.send_request() end |
#create_data_set_import_task(params = {}) ⇒ Types::CreateDataSetImportTaskResponse
Starts a data set import task for a specific application.
735 736 737 738 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 735 def create_data_set_import_task(params = {}, = {}) req = build_request(:create_data_set_import_task, params) req.send_request() end |
#create_deployment(params = {}) ⇒ Types::CreateDeploymentResponse
Creates and starts a deployment to deploy an application into a runtime environment.
785 786 787 788 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 785 def create_deployment(params = {}, = {}) req = build_request(:create_deployment, params) req.send_request() end |
#create_environment(params = {}) ⇒ Types::CreateEnvironmentResponse
Creates a runtime environment for a given runtime engine.
903 904 905 906 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 903 def create_environment(params = {}, = {}) req = build_request(:create_environment, params) req.send_request() end |
#delete_application(params = {}) ⇒ Struct
Deletes a specific application. You cannot delete a running application.
926 927 928 929 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 926 def delete_application(params = {}, = {}) req = build_request(:delete_application, params) req.send_request() end |
#delete_application_from_environment(params = {}) ⇒ Struct
Deletes a specific application from the specific runtime environment where it was previously deployed. You cannot delete a runtime environment using DeleteEnvironment if any application has ever been deployed to it. This API removes the association of the application with the runtime environment so you can delete the environment smoothly.
958 959 960 961 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 958 def delete_application_from_environment(params = {}, = {}) req = build_request(:delete_application_from_environment, params) req.send_request() end |
#delete_environment(params = {}) ⇒ Struct
Deletes a specific runtime environment. The environment cannot contain deployed applications. If it does, you must delete those applications before you delete the environment.
982 983 984 985 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 982 def delete_environment(params = {}, = {}) req = build_request(:delete_environment, params) req.send_request() end |
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Describes the details of a specific application.
1059 1060 1061 1062 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 1059 def get_application(params = {}, = {}) req = build_request(:get_application, params) req.send_request() end |
#get_application_version(params = {}) ⇒ Types::GetApplicationVersionResponse
Returns details about a specific version of a specific application.
1103 1104 1105 1106 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 1103 def get_application_version(params = {}, = {}) req = build_request(:get_application_version, params) req.send_request() end |
#get_batch_job_execution(params = {}) ⇒ Types::GetBatchJobExecutionResponse
Gets the details of a specific batch job execution for a specific application.
1178 1179 1180 1181 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 1178 def get_batch_job_execution(params = {}, = {}) req = build_request(:get_batch_job_execution, params) req.send_request() end |
#get_data_set_details(params = {}) ⇒ Types::GetDataSetDetailsResponse
Gets the details of a specific data set.
1244 1245 1246 1247 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 1244 def get_data_set_details(params = {}, = {}) req = build_request(:get_data_set_details, params) req.send_request() end |
#get_data_set_export_task(params = {}) ⇒ Types::GetDataSetExportTaskResponse
Gets the status of a data set import task initiated with the CreateDataSetExportTask operation.
1289 1290 1291 1292 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 1289 def get_data_set_export_task(params = {}, = {}) req = build_request(:get_data_set_export_task, params) req.send_request() end |
#get_data_set_import_task(params = {}) ⇒ Types::GetDataSetImportTaskResponse
Gets the status of a data set import task initiated with the CreateDataSetImportTask operation.
1330 1331 1332 1333 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 1330 def get_data_set_import_task(params = {}, = {}) req = build_request(:get_data_set_import_task, params) req.send_request() end |
#get_deployment(params = {}) ⇒ Types::GetDeploymentResponse
Gets details of a specific deployment with a given deployment identifier.
1375 1376 1377 1378 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 1375 def get_deployment(params = {}, = {}) req = build_request(:get_deployment, params) req.send_request() end |
#get_environment(params = {}) ⇒ Types::GetEnvironmentResponse
Describes a specific runtime environment.
1456 1457 1458 1459 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 1456 def get_environment(params = {}, = {}) req = build_request(:get_environment, params) req.send_request() end |
#get_signed_bluinsights_url(params = {}) ⇒ Types::GetSignedBluinsightsUrlResponse
Gets a single sign-on URL that can be used to connect to AWS Blu Insights.
1476 1477 1478 1479 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 1476 def get_signed_bluinsights_url(params = {}, = {}) req = build_request(:get_signed_bluinsights_url, params) req.send_request() end |
#list_application_versions(params = {}) ⇒ Types::ListApplicationVersionsResponse
Returns a list of the application versions for a specific application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1522 1523 1524 1525 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 1522 def list_application_versions(params = {}, = {}) req = build_request(:list_application_versions, params) req.send_request() end |
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists the applications associated with a specific Amazon Web Services account. You can provide the unique identifier of a specific runtime environment in a query parameter to see all applications associated with that environment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1584 1585 1586 1587 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 1584 def list_applications(params = {}, = {}) req = build_request(:list_applications, params) req.send_request() end |
#list_batch_job_definitions(params = {}) ⇒ Types::ListBatchJobDefinitionsResponse
Lists all the available batch job definitions based on the batch job resources uploaded during the application creation. You can use the batch job definitions in the list to start a batch job.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1636 1637 1638 1639 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 1636 def list_batch_job_definitions(params = {}, = {}) req = build_request(:list_batch_job_definitions, params) req.send_request() end |
#list_batch_job_executions(params = {}) ⇒ Types::ListBatchJobExecutionsResponse
Lists historical, current, and scheduled batch job executions for a specific application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1721 1722 1723 1724 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 1721 def list_batch_job_executions(params = {}, = {}) req = build_request(:list_batch_job_executions, params) req.send_request() end |
#list_batch_job_restart_points(params = {}) ⇒ Types::ListBatchJobRestartPointsResponse
Lists all the job steps for a JCL file to restart a batch job. This is only applicable for Micro Focus engine with versions 8.0.6 and above.
1769 1770 1771 1772 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 1769 def list_batch_job_restart_points(params = {}, = {}) req = build_request(:list_batch_job_restart_points, params) req.send_request() end |
#list_data_set_export_history(params = {}) ⇒ Types::ListDataSetExportHistoryResponse
Lists the data set exports for the specified application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1819 1820 1821 1822 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 1819 def list_data_set_export_history(params = {}, = {}) req = build_request(:list_data_set_export_history, params) req.send_request() end |
#list_data_set_import_history(params = {}) ⇒ Types::ListDataSetImportHistoryResponse
Lists the data set imports for the specified application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1869 1870 1871 1872 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 1869 def list_data_set_import_history(params = {}, = {}) req = build_request(:list_data_set_import_history, params) req.send_request() end |
#list_data_sets(params = {}) ⇒ Types::ListDataSetsResponse
Lists the data sets imported for a specific application. In Amazon Web Services Mainframe Modernization, data sets are associated with applications deployed on runtime environments. This is known as importing data sets. Currently, Amazon Web Services Mainframe Modernization can import data sets into catalogs using [CreateDataSetImportTask].
[1]: docs.aws.amazon.com/m2/latest/APIReference/API_CreateDataSetImportTask.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1937 1938 1939 1940 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 1937 def list_data_sets(params = {}, = {}) req = build_request(:list_data_sets, params) req.send_request() end |
#list_deployments(params = {}) ⇒ Types::ListDeploymentsResponse
Returns a list of all deployments of a specific application. A deployment is a combination of a specific application and a specific version of that application. Each deployment is mapped to a particular application version.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1989 1990 1991 1992 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 1989 def list_deployments(params = {}, = {}) req = build_request(:list_deployments, params) req.send_request() end |
#list_engine_versions(params = {}) ⇒ Types::ListEngineVersionsResponse
Lists the available engine versions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2033 2034 2035 2036 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 2033 def list_engine_versions(params = {}, = {}) req = build_request(:list_engine_versions, params) req.send_request() end |
#list_environments(params = {}) ⇒ Types::ListEnvironmentsResponse
Lists the runtime environments.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2088 2089 2090 2091 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 2088 def list_environments(params = {}, = {}) req = build_request(:list_environments, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
2117 2118 2119 2120 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 2117 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#start_application(params = {}) ⇒ Struct
Starts an application that is currently stopped.
2139 2140 2141 2142 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 2139 def start_application(params = {}, = {}) req = build_request(:start_application, params) req.send_request() end |
#start_batch_job(params = {}) ⇒ Types::StartBatchJobResponse
Starts a batch job and returns the unique identifier of this execution of the batch job. The associated application must be running in order to start the batch job.
2218 2219 2220 2221 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 2218 def start_batch_job(params = {}, = {}) req = build_request(:start_batch_job, params) req.send_request() end |
#stop_application(params = {}) ⇒ Struct
Stops a running application.
2247 2248 2249 2250 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 2247 def stop_application(params = {}, = {}) req = build_request(:stop_application, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to the specified resource.
2275 2276 2277 2278 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 2275 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified resource.
2301 2302 2303 2304 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 2301 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates an application and creates a new version.
2345 2346 2347 2348 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 2345 def update_application(params = {}, = {}) req = build_request(:update_application, params) req.send_request() end |
#update_environment(params = {}) ⇒ Types::UpdateEnvironmentResponse
Updates the configuration details for a specific runtime environment.
2420 2421 2422 2423 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 2420 def update_environment(params = {}, = {}) req = build_request(:update_environment, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2449 2450 2451 |
# File 'lib/aws-sdk-mainframemodernization/client.rb', line 2449 def waiter_names [] end |